# EventNotificationSubscriptionFilter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**users** | **list[str]** |  | [optional] 
**projects** | **list[str]** |  | [optional] 
**project_groups** | **list[str]** |  | [optional] 
**environments** | **list[str]** |  | [optional] 
**event_groups** | **list[str]** |  | [optional] 
**event_categories** | **list[str]** |  | [optional] 
**event_agents** | **list[str]** |  | [optional] 
**tenants** | **list[str]** |  | [optional] 
**tags** | **list[str]** |  | [optional] 
**document_types** | **list[str]** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


